"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = __importDefault(require("commander"));
const fs_1 = require("fs");
const path_1 = require("path");
const import_open_api_1 = __importDefault(require("./scripts/import-open-api"));
const log = console.log; // tslint:disable-line:no-console
commander_1.default.option('-o, --output [value]', 'output file destination');
commander_1.default.option('-f, --file [value]', 'input file (yaml or json openapi specs)');
commander_1.default.parse(process.argv);
const createSuccessMessage = (backend) => chalk_1.default.green(`${backend ? `[${backend}] ` : ''}🎉  Your OpenAPI spec has been converted into react query hooks`);
const successWithoutOutputMessage = chalk_1.default.yellow('Success! No output path specified; printed to standard output.');
const importSpecs = async (options) => {
    if (!options.file) {
        throw new Error("You need to provide an input specification with `--file`, '--url', or `--github`");
    }
    const data = fs_1.readFileSync(path_1.join(process.cwd(), options.file), 'utf-8');
    const { ext } = path_1.parse(options.file);
    const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
    return import_open_api_1.default({
        data,
        format,
    });
};
// Use flags as configuration
importSpecs(commander_1.default)
    .then((data) => {
    if (commander_1.default.output) {
        fs_1.writeFileSync(path_1.join(process.cwd(), commander_1.default.output), data);
        log(createSuccessMessage());
    }
    else {
        log(data);
        log(successWithoutOutputMessage);
    }
})
    .catch((err) => {
    log(chalk_1.default.red(err));
    process.exit(1);
});
